from ..base import AdyenServiceBase
from .pos_mobile_api import PosMobileApi


class AdyenPosMobileApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPosMobileApi, self).__init__(client=client)
        self.pos_mobile_api = PosMobileApi(client=client)
