from ..base import AdyenServiceBase
from .data_protection_api import DataProtectionApi


class AdyenDataProtectionApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenDataProtectionApi, self).__init__(client=client)
        self.data_protection_api = DataProtectionApi(client=client)
