from ..base import AdyenServiceBase
from .recurring_api import RecurringApi


class AdyenRecurringApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenRecurringApi, self).__init__(client=client)
        self.recurring_api = RecurringApi(client=client)
